# Contribute to oplog

Please refer to [Code of Conduct](CODE_OF_CONDUCT.md) for our standards of communication and behavior.

## Report a Bug

* Do not open up a GitHub issue if the bug is a security vulnerability, and instead to refer to our [security policy](https://rubyonrails.org/security).

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/oribarilan/oplog/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/oribarilan/oplog/issues/new). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** or an **executable test case** demonstrating the expected behavior that is not occurring.

## Fix a Bug

* Open a new GitHub pull request with the fix.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number.

* Make sure you follow our coding conventions. 

## Add a Feature

* `oplog` grows by tackling needs and pain of developers. First, report the issue (even if not a bug) as mentioned above ([Issues](https://github.com/oribarilan/oplog/issues)).

* Follow the same steps as for fixing a bug.


Thanks! 🧡🧡🧡

oplog Team